@@ -12,5 +12,5 @@ SPEC_ROUTE = os.environ.get("SPEC_ROUTE", "/spec")
 
 
 def setup_app(app: web.Application) -> None:
-    if SPEC_ROUTE:
+    if SPEC_ROUTE and "spec" in app:
         app.add_routes([web.get(SPEC_ROUTE, spec_root)])
