@@ -1,8 +1,11 @@
+from typing import Dict, Optional
+
 from .path import full_url
 
 
-def get_spec(request):
-    return request.app["spec_doc"].get(request)
+def get_spec(request) -> Optional[Dict]:
+    if "spec_doc" in request.app:
+        return request.app["spec_doc"].get(request)
 
 
 def default_server(request):
@@ -15,5 +18,6 @@ def default_server(request):
 def server_urls(request, paths):
     base_path = request.app["cli"].base_path
     n = len(base_path)
-    base_url = get_spec(request)["servers"][0]["url"]
+    spec = get_spec(request)
+    base_url = spec["servers"][0]["url"] if spec else "/"
     return [f"{base_url}{p[n:]}" for p in paths]
